"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class AliasRoutingStrategy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    FLEET_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    message: builtins.str
    fleet_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        message: builtins.str = ...,
        fleet_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["fleet_id", b"fleet_id", "message", b"message", "resource_info", b"resource_info"]) -> None: ...

global___AliasRoutingStrategy = AliasRoutingStrategy

@typing_extensions.final
class Alias(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ROUTING_STRATEGY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    description: builtins.str
    name: builtins.str
    @property
    def routing_strategy(self) -> global___AliasRoutingStrategy: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        description: builtins.str = ...,
        name: builtins.str = ...,
        routing_strategy: global___AliasRoutingStrategy | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "routing_strategy", b"routing_strategy"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "name", b"name", "resource_info", b"resource_info", "routing_strategy", b"routing_strategy"]) -> None: ...

global___Alias = Alias

@typing_extensions.final
class GameLift(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALIAS_FIELD_NUMBER: builtins.int
    BUILD_FIELD_NUMBER: builtins.int
    FLEET_FIELD_NUMBER: builtins.int
    GAME_SERVER_GROUP_FIELD_NUMBER: builtins.int
    GAME_SESSION_QUEUE_FIELD_NUMBER: builtins.int
    MATCHMAKING_CONFIGURATION_FIELD_NUMBER: builtins.int
    MATCHMAKING_RULE_SET_FIELD_NUMBER: builtins.int
    SCRIPT_FIELD_NUMBER: builtins.int
    @property
    def alias(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Alias]: ...
    @property
    def build(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Build]: ...
    @property
    def fleet(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Fleet]: ...
    @property
    def game_server_group(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GameServerGroup]: ...
    @property
    def game_session_queue(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GameSessionQueue]: ...
    @property
    def matchmaking_configuration(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MatchmakingConfiguration]: ...
    @property
    def matchmaking_rule_set(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MatchmakingRuleSet]: ...
    @property
    def script(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Script]: ...
    def __init__(
        self,
        *,
        alias: collections.abc.Iterable[global___Alias] | None = ...,
        build: collections.abc.Iterable[global___Build] | None = ...,
        fleet: collections.abc.Iterable[global___Fleet] | None = ...,
        game_server_group: collections.abc.Iterable[global___GameServerGroup] | None = ...,
        game_session_queue: collections.abc.Iterable[global___GameSessionQueue] | None = ...,
        matchmaking_configuration: collections.abc.Iterable[global___MatchmakingConfiguration] | None = ...,
        matchmaking_rule_set: collections.abc.Iterable[global___MatchmakingRuleSet] | None = ...,
        script: collections.abc.Iterable[global___Script] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["alias", b"alias", "build", b"build", "fleet", b"fleet", "game_server_group", b"game_server_group", "game_session_queue", b"game_session_queue", "matchmaking_configuration", b"matchmaking_configuration", "matchmaking_rule_set", b"matchmaking_rule_set", "script", b"script"]) -> None: ...

global___GameLift = GameLift

@typing_extensions.final
class BuildS3Location(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    BUCKET_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    OBJECT_VERSION_FIELD_NUMBER: builtins.int
    ROLE_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    bucket: builtins.str
    key: builtins.str
    object_version: builtins.str
    role_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        bucket: builtins.str = ...,
        key: builtins.str = ...,
        object_version: builtins.str = ...,
        role_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bucket", b"bucket", "key", b"key", "object_version", b"object_version", "resource_info", b"resource_info", "role_arn", b"role_arn"]) -> None: ...

global___BuildS3Location = BuildS3Location

@typing_extensions.final
class Build(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    OPERATING_SYSTEM_FIELD_NUMBER: builtins.int
    STORAGE_LOCATION_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    operating_system: builtins.str
    @property
    def storage_location(self) -> global___BuildS3Location: ...
    version: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        operating_system: builtins.str = ...,
        storage_location: global___BuildS3Location | None = ...,
        version: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "storage_location", b"storage_location"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "operating_system", b"operating_system", "resource_info", b"resource_info", "storage_location", b"storage_location", "version", b"version"]) -> None: ...

global___Build = Build

@typing_extensions.final
class FleetCertificateConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CERTIFICATE_TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    certificate_type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        certificate_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["certificate_type", b"certificate_type", "resource_info", b"resource_info"]) -> None: ...

global___FleetCertificateConfiguration = FleetCertificateConfiguration

@typing_extensions.final
class FleetIpPermission(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    FROM_PORT_FIELD_NUMBER: builtins.int
    IP_RANGE_FIELD_NUMBER: builtins.int
    PROTOCOL_FIELD_NUMBER: builtins.int
    TO_PORT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    from_port: builtins.int
    ip_range: builtins.str
    protocol: builtins.str
    to_port: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        from_port: builtins.int = ...,
        ip_range: builtins.str = ...,
        protocol: builtins.str = ...,
        to_port: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["from_port", b"from_port", "ip_range", b"ip_range", "protocol", b"protocol", "resource_info", b"resource_info", "to_port", b"to_port"]) -> None: ...

global___FleetIpPermission = FleetIpPermission

@typing_extensions.final
class FleetResourceCreationLimitPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NEW_GAME_SESSIONS_PER_CREATOR_FIELD_NUMBER: builtins.int
    POLICY_PERIOD_IN_MINUTES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    new_game_sessions_per_creator: builtins.int
    policy_period_in_minutes: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        new_game_sessions_per_creator: builtins.int = ...,
        policy_period_in_minutes: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["new_game_sessions_per_creator", b"new_game_sessions_per_creator", "policy_period_in_minutes", b"policy_period_in_minutes", "resource_info", b"resource_info"]) -> None: ...

global___FleetResourceCreationLimitPolicy = FleetResourceCreationLimitPolicy

@typing_extensions.final
class FleetServerProcess(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CONCURRENT_EXECUTIONS_FIELD_NUMBER: builtins.int
    LAUNCH_PATH_FIELD_NUMBER: builtins.int
    PARAMETERS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    concurrent_executions: builtins.int
    launch_path: builtins.str
    parameters: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        concurrent_executions: builtins.int = ...,
        launch_path: builtins.str = ...,
        parameters: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["concurrent_executions", b"concurrent_executions", "launch_path", b"launch_path", "parameters", b"parameters", "resource_info", b"resource_info"]) -> None: ...

global___FleetServerProcess = FleetServerProcess

@typing_extensions.final
class FleetRuntimeConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    GAME_SESSION_ACTIVATION_TIMEOUT_SECONDS_FIELD_NUMBER: builtins.int
    MAX_CONCURRENT_GAME_SESSION_ACTIVATIONS_FIELD_NUMBER: builtins.int
    SERVER_PROCESSES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    game_session_activation_timeout_seconds: builtins.int
    max_concurrent_game_session_activations: builtins.int
    @property
    def server_processes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FleetServerProcess]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        game_session_activation_timeout_seconds: builtins.int = ...,
        max_concurrent_game_session_activations: builtins.int = ...,
        server_processes: collections.abc.Iterable[global___FleetServerProcess] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["game_session_activation_timeout_seconds", b"game_session_activation_timeout_seconds", "max_concurrent_game_session_activations", b"max_concurrent_game_session_activations", "resource_info", b"resource_info", "server_processes", b"server_processes"]) -> None: ...

global___FleetRuntimeConfiguration = FleetRuntimeConfiguration

@typing_extensions.final
class Fleet(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    BUILD_ID_FIELD_NUMBER: builtins.int
    CERTIFICATE_CONFIGURATION_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DESIRED_E_C2_INSTANCES_FIELD_NUMBER: builtins.int
    E_C2_INBOUND_PERMISSIONS_FIELD_NUMBER: builtins.int
    E_C2_INSTANCE_TYPE_FIELD_NUMBER: builtins.int
    FLEET_TYPE_FIELD_NUMBER: builtins.int
    INSTANCE_ROLE_ARN_FIELD_NUMBER: builtins.int
    LOG_PATHS_FIELD_NUMBER: builtins.int
    MAX_SIZE_FIELD_NUMBER: builtins.int
    METRIC_GROUPS_FIELD_NUMBER: builtins.int
    MIN_SIZE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NEW_GAME_SESSION_PROTECTION_POLICY_FIELD_NUMBER: builtins.int
    PEER_VPC_AWS_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    PEER_VPC_ID_FIELD_NUMBER: builtins.int
    RESOURCE_CREATION_LIMIT_POLICY_FIELD_NUMBER: builtins.int
    RUNTIME_CONFIGURATION_FIELD_NUMBER: builtins.int
    SCRIPT_ID_FIELD_NUMBER: builtins.int
    SERVER_LAUNCH_PARAMETERS_FIELD_NUMBER: builtins.int
    SERVER_LAUNCH_PATH_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    build_id: builtins.str
    @property
    def certificate_configuration(self) -> global___FleetCertificateConfiguration: ...
    description: builtins.str
    desired_e_c2_instances: builtins.int
    @property
    def e_c2_inbound_permissions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FleetIpPermission]: ...
    e_c2_instance_type: builtins.str
    fleet_type: builtins.str
    instance_role_arn: builtins.str
    @property
    def log_paths(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    max_size: builtins.int
    @property
    def metric_groups(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    min_size: builtins.int
    name: builtins.str
    new_game_session_protection_policy: builtins.str
    peer_vpc_aws_account_id: builtins.str
    peer_vpc_id: builtins.str
    @property
    def resource_creation_limit_policy(self) -> global___FleetResourceCreationLimitPolicy: ...
    @property
    def runtime_configuration(self) -> global___FleetRuntimeConfiguration: ...
    script_id: builtins.str
    server_launch_parameters: builtins.str
    server_launch_path: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        build_id: builtins.str = ...,
        certificate_configuration: global___FleetCertificateConfiguration | None = ...,
        description: builtins.str = ...,
        desired_e_c2_instances: builtins.int = ...,
        e_c2_inbound_permissions: collections.abc.Iterable[global___FleetIpPermission] | None = ...,
        e_c2_instance_type: builtins.str = ...,
        fleet_type: builtins.str = ...,
        instance_role_arn: builtins.str = ...,
        log_paths: collections.abc.Iterable[builtins.str] | None = ...,
        max_size: builtins.int = ...,
        metric_groups: collections.abc.Iterable[builtins.str] | None = ...,
        min_size: builtins.int = ...,
        name: builtins.str = ...,
        new_game_session_protection_policy: builtins.str = ...,
        peer_vpc_aws_account_id: builtins.str = ...,
        peer_vpc_id: builtins.str = ...,
        resource_creation_limit_policy: global___FleetResourceCreationLimitPolicy | None = ...,
        runtime_configuration: global___FleetRuntimeConfiguration | None = ...,
        script_id: builtins.str = ...,
        server_launch_parameters: builtins.str = ...,
        server_launch_path: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["certificate_configuration", b"certificate_configuration", "resource_creation_limit_policy", b"resource_creation_limit_policy", "resource_info", b"resource_info", "runtime_configuration", b"runtime_configuration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["build_id", b"build_id", "certificate_configuration", b"certificate_configuration", "description", b"description", "desired_e_c2_instances", b"desired_e_c2_instances", "e_c2_inbound_permissions", b"e_c2_inbound_permissions", "e_c2_instance_type", b"e_c2_instance_type", "fleet_type", b"fleet_type", "instance_role_arn", b"instance_role_arn", "log_paths", b"log_paths", "max_size", b"max_size", "metric_groups", b"metric_groups", "min_size", b"min_size", "name", b"name", "new_game_session_protection_policy", b"new_game_session_protection_policy", "peer_vpc_aws_account_id", b"peer_vpc_aws_account_id", "peer_vpc_id", b"peer_vpc_id", "resource_creation_limit_policy", b"resource_creation_limit_policy", "resource_info", b"resource_info", "runtime_configuration", b"runtime_configuration", "script_id", b"script_id", "server_launch_parameters", b"server_launch_parameters", "server_launch_path", b"server_launch_path"]) -> None: ...

global___Fleet = Fleet

@typing_extensions.final
class GameServerGroupTargetTrackingConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    TARGET_VALUE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    target_value: builtins.float
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        target_value: builtins.float = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "target_value", b"target_value"]) -> None: ...

global___GameServerGroupTargetTrackingConfiguration = GameServerGroupTargetTrackingConfiguration

@typing_extensions.final
class GameServerGroupAutoScalingPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ESTIMATED_INSTANCE_WARMUP_FIELD_NUMBER: builtins.int
    TARGET_TRACKING_CONFIGURATION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    estimated_instance_warmup: builtins.float
    @property
    def target_tracking_configuration(self) -> global___GameServerGroupTargetTrackingConfiguration: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        estimated_instance_warmup: builtins.float = ...,
        target_tracking_configuration: global___GameServerGroupTargetTrackingConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "target_tracking_configuration", b"target_tracking_configuration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["estimated_instance_warmup", b"estimated_instance_warmup", "resource_info", b"resource_info", "target_tracking_configuration", b"target_tracking_configuration"]) -> None: ...

global___GameServerGroupAutoScalingPolicy = GameServerGroupAutoScalingPolicy

@typing_extensions.final
class GameServerGroupInstanceDefinition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    INSTANCE_TYPE_FIELD_NUMBER: builtins.int
    WEIGHTED_CAPACITY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    instance_type: builtins.str
    weighted_capacity: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        instance_type: builtins.str = ...,
        weighted_capacity: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["instance_type", b"instance_type", "resource_info", b"resource_info", "weighted_capacity", b"weighted_capacity"]) -> None: ...

global___GameServerGroupInstanceDefinition = GameServerGroupInstanceDefinition

@typing_extensions.final
class GameServerGroupInstanceDefinitions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    INSTANCE_DEFINITIONS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def instance_definitions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GameServerGroupInstanceDefinition]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        instance_definitions: collections.abc.Iterable[global___GameServerGroupInstanceDefinition] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["instance_definitions", b"instance_definitions", "resource_info", b"resource_info"]) -> None: ...

global___GameServerGroupInstanceDefinitions = GameServerGroupInstanceDefinitions

@typing_extensions.final
class GameServerGroupLaunchTemplate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    LAUNCH_TEMPLATE_ID_FIELD_NUMBER: builtins.int
    LAUNCH_TEMPLATE_NAME_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    launch_template_id: builtins.str
    launch_template_name: builtins.str
    version: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        launch_template_id: builtins.str = ...,
        launch_template_name: builtins.str = ...,
        version: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["launch_template_id", b"launch_template_id", "launch_template_name", b"launch_template_name", "resource_info", b"resource_info", "version", b"version"]) -> None: ...

global___GameServerGroupLaunchTemplate = GameServerGroupLaunchTemplate

@typing_extensions.final
class GameServerGroupTags(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___GameServerGroupTags = GameServerGroupTags

@typing_extensions.final
class GameServerGroupVpcSubnets(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    VPC_SUBNETS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def vpc_subnets(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        vpc_subnets: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "vpc_subnets", b"vpc_subnets"]) -> None: ...

global___GameServerGroupVpcSubnets = GameServerGroupVpcSubnets

@typing_extensions.final
class GameServerGroup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    AUTO_SCALING_POLICY_FIELD_NUMBER: builtins.int
    BALANCING_STRATEGY_FIELD_NUMBER: builtins.int
    DELETE_OPTION_FIELD_NUMBER: builtins.int
    GAME_SERVER_GROUP_NAME_FIELD_NUMBER: builtins.int
    GAME_SERVER_PROTECTION_POLICY_FIELD_NUMBER: builtins.int
    INSTANCE_DEFINITIONS_FIELD_NUMBER: builtins.int
    LAUNCH_TEMPLATE_FIELD_NUMBER: builtins.int
    MAX_SIZE_FIELD_NUMBER: builtins.int
    MIN_SIZE_FIELD_NUMBER: builtins.int
    ROLE_ARN_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    VPC_SUBNETS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def auto_scaling_policy(self) -> global___GameServerGroupAutoScalingPolicy: ...
    balancing_strategy: builtins.str
    delete_option: builtins.str
    game_server_group_name: builtins.str
    game_server_protection_policy: builtins.str
    @property
    def instance_definitions(self) -> global___GameServerGroupInstanceDefinitions: ...
    @property
    def launch_template(self) -> global___GameServerGroupLaunchTemplate: ...
    max_size: builtins.float
    min_size: builtins.float
    role_arn: builtins.str
    @property
    def tags(self) -> global___GameServerGroupTags: ...
    @property
    def vpc_subnets(self) -> global___GameServerGroupVpcSubnets: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        auto_scaling_policy: global___GameServerGroupAutoScalingPolicy | None = ...,
        balancing_strategy: builtins.str = ...,
        delete_option: builtins.str = ...,
        game_server_group_name: builtins.str = ...,
        game_server_protection_policy: builtins.str = ...,
        instance_definitions: global___GameServerGroupInstanceDefinitions | None = ...,
        launch_template: global___GameServerGroupLaunchTemplate | None = ...,
        max_size: builtins.float = ...,
        min_size: builtins.float = ...,
        role_arn: builtins.str = ...,
        tags: global___GameServerGroupTags | None = ...,
        vpc_subnets: global___GameServerGroupVpcSubnets | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["auto_scaling_policy", b"auto_scaling_policy", "instance_definitions", b"instance_definitions", "launch_template", b"launch_template", "resource_info", b"resource_info", "tags", b"tags", "vpc_subnets", b"vpc_subnets"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auto_scaling_policy", b"auto_scaling_policy", "balancing_strategy", b"balancing_strategy", "delete_option", b"delete_option", "game_server_group_name", b"game_server_group_name", "game_server_protection_policy", b"game_server_protection_policy", "instance_definitions", b"instance_definitions", "launch_template", b"launch_template", "max_size", b"max_size", "min_size", b"min_size", "resource_info", b"resource_info", "role_arn", b"role_arn", "tags", b"tags", "vpc_subnets", b"vpc_subnets"]) -> None: ...

global___GameServerGroup = GameServerGroup

@typing_extensions.final
class GameSessionQueuePlayerLatencyPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    POLICY_DURATION_SECONDS_FIELD_NUMBER: builtins.int
    MAXIMUM_INDIVIDUAL_PLAYER_LATENCY_MILLISECONDS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    policy_duration_seconds: builtins.int
    maximum_individual_player_latency_milliseconds: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        policy_duration_seconds: builtins.int = ...,
        maximum_individual_player_latency_milliseconds: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["maximum_individual_player_latency_milliseconds", b"maximum_individual_player_latency_milliseconds", "policy_duration_seconds", b"policy_duration_seconds", "resource_info", b"resource_info"]) -> None: ...

global___GameSessionQueuePlayerLatencyPolicy = GameSessionQueuePlayerLatencyPolicy

@typing_extensions.final
class GameSessionQueueDestination(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DESTINATION_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    destination_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        destination_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["destination_arn", b"destination_arn", "resource_info", b"resource_info"]) -> None: ...

global___GameSessionQueueDestination = GameSessionQueueDestination

@typing_extensions.final
class GameSessionQueue(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    TIMEOUT_IN_SECONDS_FIELD_NUMBER: builtins.int
    PLAYER_LATENCY_POLICIES_FIELD_NUMBER: builtins.int
    DESTINATIONS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    timeout_in_seconds: builtins.int
    @property
    def player_latency_policies(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GameSessionQueuePlayerLatencyPolicy]: ...
    @property
    def destinations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GameSessionQueueDestination]: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        timeout_in_seconds: builtins.int = ...,
        player_latency_policies: collections.abc.Iterable[global___GameSessionQueuePlayerLatencyPolicy] | None = ...,
        destinations: collections.abc.Iterable[global___GameSessionQueueDestination] | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["destinations", b"destinations", "name", b"name", "player_latency_policies", b"player_latency_policies", "resource_info", b"resource_info", "timeout_in_seconds", b"timeout_in_seconds"]) -> None: ...

global___GameSessionQueue = GameSessionQueue

@typing_extensions.final
class MatchmakingConfigurationGameProperty(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    value: builtins.str
    key: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        value: builtins.str = ...,
        key: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "resource_info", b"resource_info", "value", b"value"]) -> None: ...

global___MatchmakingConfigurationGameProperty = MatchmakingConfigurationGameProperty

@typing_extensions.final
class MatchmakingConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    GAME_PROPERTIES_FIELD_NUMBER: builtins.int
    GAME_SESSION_DATA_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ACCEPTANCE_TIMEOUT_SECONDS_FIELD_NUMBER: builtins.int
    NOTIFICATION_TARGET_FIELD_NUMBER: builtins.int
    CUSTOM_EVENT_DATA_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ADDITIONAL_PLAYER_COUNT_FIELD_NUMBER: builtins.int
    BACKFILL_MODE_FIELD_NUMBER: builtins.int
    REQUEST_TIMEOUT_SECONDS_FIELD_NUMBER: builtins.int
    ACCEPTANCE_REQUIRED_FIELD_NUMBER: builtins.int
    RULE_SET_NAME_FIELD_NUMBER: builtins.int
    GAME_SESSION_QUEUE_ARNS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def game_properties(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MatchmakingConfigurationGameProperty]: ...
    game_session_data: builtins.str
    description: builtins.str
    acceptance_timeout_seconds: builtins.int
    notification_target: builtins.str
    custom_event_data: builtins.str
    name: builtins.str
    additional_player_count: builtins.int
    backfill_mode: builtins.str
    request_timeout_seconds: builtins.int
    acceptance_required: builtins.bool
    rule_set_name: builtins.str
    @property
    def game_session_queue_arns(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        game_properties: collections.abc.Iterable[global___MatchmakingConfigurationGameProperty] | None = ...,
        game_session_data: builtins.str = ...,
        description: builtins.str = ...,
        acceptance_timeout_seconds: builtins.int = ...,
        notification_target: builtins.str = ...,
        custom_event_data: builtins.str = ...,
        name: builtins.str = ...,
        additional_player_count: builtins.int = ...,
        backfill_mode: builtins.str = ...,
        request_timeout_seconds: builtins.int = ...,
        acceptance_required: builtins.bool = ...,
        rule_set_name: builtins.str = ...,
        game_session_queue_arns: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["acceptance_required", b"acceptance_required", "acceptance_timeout_seconds", b"acceptance_timeout_seconds", "additional_player_count", b"additional_player_count", "backfill_mode", b"backfill_mode", "custom_event_data", b"custom_event_data", "description", b"description", "game_properties", b"game_properties", "game_session_data", b"game_session_data", "game_session_queue_arns", b"game_session_queue_arns", "name", b"name", "notification_target", b"notification_target", "request_timeout_seconds", b"request_timeout_seconds", "resource_info", b"resource_info", "rule_set_name", b"rule_set_name"]) -> None: ...

global___MatchmakingConfiguration = MatchmakingConfiguration

@typing_extensions.final
class MatchmakingRuleSet(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    RULE_SET_BODY_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    rule_set_body: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        rule_set_body: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info", "rule_set_body", b"rule_set_body"]) -> None: ...

global___MatchmakingRuleSet = MatchmakingRuleSet

@typing_extensions.final
class ScriptS3Location(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    OBJECT_VERSION_FIELD_NUMBER: builtins.int
    BUCKET_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    ROLE_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    object_version: builtins.str
    bucket: builtins.str
    key: builtins.str
    role_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        object_version: builtins.str = ...,
        bucket: builtins.str = ...,
        key: builtins.str = ...,
        role_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bucket", b"bucket", "key", b"key", "object_version", b"object_version", "resource_info", b"resource_info", "role_arn", b"role_arn"]) -> None: ...

global___ScriptS3Location = ScriptS3Location

@typing_extensions.final
class Script(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    STORAGE_LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    version: builtins.str
    @property
    def storage_location(self) -> global___ScriptS3Location: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        version: builtins.str = ...,
        storage_location: global___ScriptS3Location | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "storage_location", b"storage_location"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info", "storage_location", b"storage_location", "version", b"version"]) -> None: ...

global___Script = Script



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class PipelineParameterAttribute(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    STRING_VALUE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    key: builtins.str
    string_value: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        key: builtins.str = ...,
        string_value: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "resource_info", b"resource_info", "string_value", b"string_value"]) -> None: ...

global___PipelineParameterAttribute = PipelineParameterAttribute

@typing_extensions.final
class PipelineParameterObject(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ATTRIBUTES_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def attributes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PipelineParameterAttribute]: ...
    id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        attributes: collections.abc.Iterable[global___PipelineParameterAttribute] | None = ...,
        id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["attributes", b"attributes", "id", b"id", "resource_info", b"resource_info"]) -> None: ...

global___PipelineParameterObject = PipelineParameterObject

@typing_extensions.final
class PipelineParameterValue(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    STRING_VALUE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    id: builtins.str
    string_value: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        id: builtins.str = ...,
        string_value: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "resource_info", b"resource_info", "string_value", b"string_value"]) -> None: ...

global___PipelineParameterValue = PipelineParameterValue

@typing_extensions.final
class PipelineField(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    REF_VALUE_FIELD_NUMBER: builtins.int
    STRING_VALUE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    key: builtins.str
    ref_value: builtins.str
    string_value: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        key: builtins.str = ...,
        ref_value: builtins.str = ...,
        string_value: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "ref_value", b"ref_value", "resource_info", b"resource_info", "string_value", b"string_value"]) -> None: ...

global___PipelineField = PipelineField

@typing_extensions.final
class PipelinePipelineObject(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    FIELDS_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def fields(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PipelineField]: ...
    id: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        fields: collections.abc.Iterable[global___PipelineField] | None = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["fields", b"fields", "id", b"id", "name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___PipelinePipelineObject = PipelinePipelineObject

@typing_extensions.final
class PipelinePipelineTag(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    key: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        key: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "resource_info", b"resource_info", "value", b"value"]) -> None: ...

global___PipelinePipelineTag = PipelinePipelineTag

@typing_extensions.final
class Pipeline(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ACTIVATE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PARAMETER_OBJECTS_FIELD_NUMBER: builtins.int
    PARAMETER_VALUES_FIELD_NUMBER: builtins.int
    PIPELINE_OBJECTS_FIELD_NUMBER: builtins.int
    PIPELINE_TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    activate: builtins.bool
    description: builtins.str
    name: builtins.str
    @property
    def parameter_objects(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PipelineParameterObject]: ...
    @property
    def parameter_values(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PipelineParameterValue]: ...
    @property
    def pipeline_objects(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PipelinePipelineObject]: ...
    @property
    def pipeline_tags(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PipelinePipelineTag]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        activate: builtins.bool = ...,
        description: builtins.str = ...,
        name: builtins.str = ...,
        parameter_objects: collections.abc.Iterable[global___PipelineParameterObject] | None = ...,
        parameter_values: collections.abc.Iterable[global___PipelineParameterValue] | None = ...,
        pipeline_objects: collections.abc.Iterable[global___PipelinePipelineObject] | None = ...,
        pipeline_tags: collections.abc.Iterable[global___PipelinePipelineTag] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["activate", b"activate", "description", b"description", "name", b"name", "parameter_objects", b"parameter_objects", "parameter_values", b"parameter_values", "pipeline_objects", b"pipeline_objects", "pipeline_tags", b"pipeline_tags", "resource_info", b"resource_info"]) -> None: ...

global___Pipeline = Pipeline

@typing_extensions.final
class DataPipeline(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PIPELINE_FIELD_NUMBER: builtins.int
    @property
    def pipeline(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Pipeline]: ...
    def __init__(
        self,
        *,
        pipeline: collections.abc.Iterable[global___Pipeline] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["pipeline", b"pipeline"]) -> None: ...

global___DataPipeline = DataPipeline



from oak9.sac_framework.core.types import Context


class Capability():
    _Id: str = None
    _Name: str = None

    def __init__(self, context: Context):
        # apply business context
        self._context = context

    def id(self):
        return self._Id

    def name(self):
        return self._Name



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class RecaptchaEnterpriseKeyXAndroidSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOW_ALL_PACKAGE_NAMES_FIELD_NUMBER: builtins.int
    ALLOWED_PACKAGE_NAMES_FIELD_NUMBER: builtins.int
    allow_all_package_names: builtins.bool
    @property
    def allowed_package_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        allow_all_package_names: builtins.bool = ...,
        allowed_package_names: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["allow_all_package_names", b"allow_all_package_names", "allowed_package_names", b"allowed_package_names"]) -> None: ...

global___RecaptchaEnterpriseKeyXAndroidSettings = RecaptchaEnterpriseKeyXAndroidSettings

@typing_extensions.final
class RecaptchaEnterpriseKeyXIosSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOW_ALL_BUNDLE_IDS_FIELD_NUMBER: builtins.int
    ALLOWED_BUNDLE_IDS_FIELD_NUMBER: builtins.int
    allow_all_bundle_ids: builtins.bool
    @property
    def allowed_bundle_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        allow_all_bundle_ids: builtins.bool = ...,
        allowed_bundle_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["allow_all_bundle_ids", b"allow_all_bundle_ids", "allowed_bundle_ids", b"allowed_bundle_ids"]) -> None: ...

global___RecaptchaEnterpriseKeyXIosSettings = RecaptchaEnterpriseKeyXIosSettings

@typing_extensions.final
class RecaptchaEnterpriseKeyXTestingOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TESTING_CHALLENGE_FIELD_NUMBER: builtins.int
    TESTING_SCORE_FIELD_NUMBER: builtins.int
    testing_challenge: builtins.str
    testing_score: builtins.float
    def __init__(
        self,
        *,
        testing_challenge: builtins.str = ...,
        testing_score: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["testing_challenge", b"testing_challenge", "testing_score", b"testing_score"]) -> None: ...

global___RecaptchaEnterpriseKeyXTestingOptions = RecaptchaEnterpriseKeyXTestingOptions

@typing_extensions.final
class RecaptchaEnterpriseKeyXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___RecaptchaEnterpriseKeyXTimeouts = RecaptchaEnterpriseKeyXTimeouts

@typing_extensions.final
class RecaptchaEnterpriseKeyXWebSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOW_ALL_DOMAINS_FIELD_NUMBER: builtins.int
    ALLOW_AMP_TRAFFIC_FIELD_NUMBER: builtins.int
    ALLOWED_DOMAINS_FIELD_NUMBER: builtins.int
    CHALLENGE_SECURITY_PREFERENCE_FIELD_NUMBER: builtins.int
    INTEGRATION_TYPE_FIELD_NUMBER: builtins.int
    allow_all_domains: builtins.bool
    allow_amp_traffic: builtins.bool
    @property
    def allowed_domains(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    challenge_security_preference: builtins.str
    integration_type: builtins.str
    def __init__(
        self,
        *,
        allow_all_domains: builtins.bool = ...,
        allow_amp_traffic: builtins.bool = ...,
        allowed_domains: collections.abc.Iterable[builtins.str] | None = ...,
        challenge_security_preference: builtins.str = ...,
        integration_type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["allow_all_domains", b"allow_all_domains", "allow_amp_traffic", b"allow_amp_traffic", "allowed_domains", b"allowed_domains", "challenge_security_preference", b"challenge_security_preference", "integration_type", b"integration_type"]) -> None: ...

global___RecaptchaEnterpriseKeyXWebSettings = RecaptchaEnterpriseKeyXWebSettings

@typing_extensions.final
class RecaptchaEnterpriseKey(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    CREATE_TIME_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    ANDROID_SETTINGS_FIELD_NUMBER: builtins.int
    IOS_SETTINGS_FIELD_NUMBER: builtins.int
    TESTING_OPTIONS_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    WEB_SETTINGS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    create_time: builtins.str
    display_name: builtins.str
    id: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    name: builtins.str
    project: builtins.str
    @property
    def android_settings(self) -> global___RecaptchaEnterpriseKeyXAndroidSettings: ...
    @property
    def ios_settings(self) -> global___RecaptchaEnterpriseKeyXIosSettings: ...
    @property
    def testing_options(self) -> global___RecaptchaEnterpriseKeyXTestingOptions: ...
    @property
    def timeouts(self) -> global___RecaptchaEnterpriseKeyXTimeouts: ...
    @property
    def web_settings(self) -> global___RecaptchaEnterpriseKeyXWebSettings: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        create_time: builtins.str = ...,
        display_name: builtins.str = ...,
        id: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        android_settings: global___RecaptchaEnterpriseKeyXAndroidSettings | None = ...,
        ios_settings: global___RecaptchaEnterpriseKeyXIosSettings | None = ...,
        testing_options: global___RecaptchaEnterpriseKeyXTestingOptions | None = ...,
        timeouts: global___RecaptchaEnterpriseKeyXTimeouts | None = ...,
        web_settings: global___RecaptchaEnterpriseKeyXWebSettings | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["android_settings", b"android_settings", "ios_settings", b"ios_settings", "resource_info", b"resource_info", "testing_options", b"testing_options", "timeouts", b"timeouts", "web_settings", b"web_settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["android_settings", b"android_settings", "create_time", b"create_time", "display_name", b"display_name", "id", b"id", "ios_settings", b"ios_settings", "labels", b"labels", "name", b"name", "project", b"project", "resource_info", b"resource_info", "testing_options", b"testing_options", "timeouts", b"timeouts", "web_settings", b"web_settings"]) -> None: ...

global___RecaptchaEnterpriseKey = RecaptchaEnterpriseKey



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class GitHubRepositoryS3(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    OBJECT_VERSION_FIELD_NUMBER: builtins.int
    BUCKET_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    object_version: builtins.str
    bucket: builtins.str
    key: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        object_version: builtins.str = ...,
        bucket: builtins.str = ...,
        key: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bucket", b"bucket", "key", b"key", "object_version", b"object_version", "resource_info", b"resource_info"]) -> None: ...

global___GitHubRepositoryS3 = GitHubRepositoryS3

@typing_extensions.final
class GitHubRepositoryCode(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    S3_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def s3(self) -> global___GitHubRepositoryS3: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        s3: global___GitHubRepositoryS3 | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "s3", b"s3"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "s3", b"s3"]) -> None: ...

global___GitHubRepositoryCode = GitHubRepositoryCode

@typing_extensions.final
class GitHubRepository(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ENABLE_ISSUES_FIELD_NUMBER: builtins.int
    REPOSITORY_NAME_FIELD_NUMBER: builtins.int
    REPOSITORY_ACCESS_TOKEN_FIELD_NUMBER: builtins.int
    REPOSITORY_OWNER_FIELD_NUMBER: builtins.int
    IS_PRIVATE_FIELD_NUMBER: builtins.int
    CODE_FIELD_NUMBER: builtins.int
    REPOSITORY_DESCRIPTION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    enable_issues: builtins.bool
    repository_name: builtins.str
    repository_access_token: builtins.str
    repository_owner: builtins.str
    is_private: builtins.bool
    @property
    def code(self) -> global___GitHubRepositoryCode: ...
    repository_description: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        enable_issues: builtins.bool = ...,
        repository_name: builtins.str = ...,
        repository_access_token: builtins.str = ...,
        repository_owner: builtins.str = ...,
        is_private: builtins.bool = ...,
        code: global___GitHubRepositoryCode | None = ...,
        repository_description: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["code", b"code", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["code", b"code", "enable_issues", b"enable_issues", "is_private", b"is_private", "repository_access_token", b"repository_access_token", "repository_description", b"repository_description", "repository_name", b"repository_name", "repository_owner", b"repository_owner", "resource_info", b"resource_info"]) -> None: ...

global___GitHubRepository = GitHubRepository

@typing_extensions.final
class CodeStar(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GIT_HUB_REPOSITORY_FIELD_NUMBER: builtins.int
    @property
    def git_hub_repository(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GitHubRepository]: ...
    def __init__(
        self,
        *,
        git_hub_repository: collections.abc.Iterable[global___GitHubRepository] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["git_hub_repository", b"git_hub_repository"]) -> None: ...

global___CodeStar = CodeStar



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_emr.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x61ws/aws_emr.proto\x12\x13oak9.tython.aws.emr\x1a\x13shared/shared.proto\"\x87\x02\n\x12\x43lusterApplication\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12T\n\x0f\x61\x64\x64itional_info\x18\x02 \x03(\x0b\x32;.oak9.tython.aws.emr.ClusterApplication.AdditionalInfoEntry\x12\x0c\n\x04\x61rgs\x18\x03 \x03(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0f\n\x07version\x18\x05 \x01(\t\x1a\x35\n\x13\x41\x64\x64itionalInfoEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"y\n\"ClusterScriptBootstrapActionConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04\x61rgs\x18\x02 \x03(\t\x12\x0c\n\x04path\x18\x03 \x01(\t\"\xbf\x01\n\x1c\x43lusterBootstrapActionConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12X\n\x17script_bootstrap_action\x18\x03 \x01(\x0b\x32\x37.oak9.tython.aws.emr.ClusterScriptBootstrapActionConfig\"\xd4\x02\n\x14\x43lusterConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0e\x63lassification\x18\x02 \x01(\t\x12h\n\x18\x63onfiguration_properties\x18\x03 \x03(\x0b\x32\x46.oak9.tython.aws.emr.ClusterConfiguration.ConfigurationPropertiesEntry\x12\x41\n\x0e\x63onfigurations\x18\x04 \x03(\x0b\x32).oak9.tython.aws.emr.ClusterConfiguration\x1a>\n\x1c\x43onfigurationPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8c\x01\n\x1a\x43lusterVolumeSpecification\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04iops\x18\x02 \x01(\x05\x12\x12\n\nsize_in_gb\x18\x03 \x01(\x05\x12\x13\n\x0bvolume_type\x18\x04 \x01(\t\"\xc3\x01\n\x1b\x43lusterEbsBlockDeviceConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12M\n\x14volume_specification\x18\x02 \x01(\x0b\x32/.oak9.tython.aws.emr.ClusterVolumeSpecification\x12\x1c\n\x14volumes_per_instance\x18\x03 \x01(\x05\"\xbd\x01\n\x17\x43lusterEbsConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12R\n\x18\x65\x62s_block_device_configs\x18\x02 \x03(\x0b\x32\x30.oak9.tython.aws.emr.ClusterEbsBlockDeviceConfig\x12\x15\n\rebs_optimized\x18\x03 \x01(\x08\"\xd9\x02\n\x19\x43lusterInstanceTypeConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\tbid_price\x18\x02 \x01(\t\x12\x32\n*bid_price_as_percentage_of_on_demand_price\x18\x03 \x01(\x01\x12\x41\n\x0e\x63onfigurations\x18\x04 \x03(\x0b\x32).oak9.tython.aws.emr.ClusterConfiguration\x12G\n\x11\x65\x62s_configuration\x18\x05 \x01(\x0b\x32,.oak9.tython.aws.emr.ClusterEbsConfiguration\x12\x15\n\rinstance_type\x18\x06 \x01(\t\x12\x19\n\x11weighted_capacity\x18\x07 \x01(\x05\"\xb9\x01\n$ClusterSpotProvisioningSpecification\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1e\n\x16\x62lock_duration_minutes\x18\x02 \x01(\x05\x12\x16\n\x0etimeout_action\x18\x03 \x01(\t\x12 \n\x18timeout_duration_minutes\x18\x04 \x01(\x05\"\xc0\x01\n.ClusterInstanceFleetProvisioningSpecifications\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12U\n\x12spot_specification\x18\x02 \x01(\x0b\x32\x39.oak9.tython.aws.emr.ClusterSpotProvisioningSpecification\"\xd7\x02\n\x1a\x43lusterInstanceFleetConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12M\n\x15instance_type_configs\x18\x02 \x03(\x0b\x32..oak9.tython.aws.emr.ClusterInstanceTypeConfig\x12\x62\n\x15launch_specifications\x18\x03 \x01(\x0b\x32\x43.oak9.tython.aws.emr.ClusterInstanceFleetProvisioningSpecifications\x12\x0c\n\x04name\x18\x04 \x01(\t\x12!\n\x19target_on_demand_capacity\x18\x05 \x01(\x05\x12\x1c\n\x14target_spot_capacity\x18\x06 \x01(\x05\"\x80\x01\n\x19\x43lusterScalingConstraints\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0cmax_capacity\x18\x02 \x01(\x05\x12\x14\n\x0cmin_capacity\x18\x03 \x01(\x05\"\xaa\x01\n\'ClusterSimpleScalingPolicyConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0f\x61\x64justment_type\x18\x02 \x01(\t\x12\x11\n\tcool_down\x18\x03 \x01(\x05\x12\x1a\n\x12scaling_adjustment\x18\x04 \x01(\x05\"\xca\x01\n\x14\x43lusterScalingAction\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06market\x18\x02 \x01(\t\x12i\n#simple_scaling_policy_configuration\x18\x03 \x01(\x0b\x32<.oak9.tython.aws.emr.ClusterSimpleScalingPolicyConfiguration\"m\n\x16\x43lusterMetricDimension\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"\xc1\x02\n ClusterCloudWatchAlarmDefinition\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1b\n\x13\x63omparison_operator\x18\x02 \x01(\t\x12?\n\ndimensions\x18\x03 \x03(\x0b\x32+.oak9.tython.aws.emr.ClusterMetricDimension\x12\x1a\n\x12\x65valuation_periods\x18\x04 \x01(\x05\x12\x13\n\x0bmetric_name\x18\x05 \x01(\t\x12\x11\n\tnamespace\x18\x06 \x01(\t\x12\x0e\n\x06period\x18\x07 \x01(\x05\x12\x11\n\tstatistic\x18\x08 \x01(\t\x12\x11\n\tthreshold\x18\t \x01(\x01\x12\x0c\n\x04unit\x18\n \x01(\t\"\xad\x01\n\x15\x43lusterScalingTrigger\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12[\n\x1c\x63loud_watch_alarm_definition\x18\x02 \x01(\x0b\x32\x35.oak9.tython.aws.emr.ClusterCloudWatchAlarmDefinition\"\xe8\x01\n\x12\x43lusterScalingRule\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x39\n\x06\x61\x63tion\x18\x02 \x01(\x0b\x32).oak9.tython.aws.emr.ClusterScalingAction\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12;\n\x07trigger\x18\x05 \x01(\x0b\x32*.oak9.tython.aws.emr.ClusterScalingTrigger\"\xd0\x01\n\x18\x43lusterAutoScalingPolicy\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x43\n\x0b\x63onstraints\x18\x02 \x01(\x0b\x32..oak9.tython.aws.emr.ClusterScalingConstraints\x12\x36\n\x05rules\x18\x03 \x03(\x0b\x32\'.oak9.tython.aws.emr.ClusterScalingRule\"\x8d\x03\n\x1a\x43lusterInstanceGroupConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12J\n\x13\x61uto_scaling_policy\x18\x02 \x01(\x0b\x32-.oak9.tython.aws.emr.ClusterAutoScalingPolicy\x12\x11\n\tbid_price\x18\x03 \x01(\t\x12\x41\n\x0e\x63onfigurations\x18\x04 \x03(\x0b\x32).oak9.tython.aws.emr.ClusterConfiguration\x12G\n\x11\x65\x62s_configuration\x18\x05 \x01(\x0b\x32,.oak9.tython.aws.emr.ClusterEbsConfiguration\x12\x16\n\x0einstance_count\x18\x06 \x01(\x05\x12\x15\n\rinstance_type\x18\x07 \x01(\t\x12\x0e\n\x06market\x18\x08 \x01(\t\x12\x0c\n\x04name\x18\t \x01(\t\"j\n\x14\x43lusterPlacementType\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x19\n\x11\x61vailability_zone\x18\x02 \x01(\t\"\xca\x06\n\x1d\x43lusterJobFlowInstancesConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12)\n!additional_master_security_groups\x18\x02 \x03(\t\x12(\n additional_slave_security_groups\x18\x03 \x03(\t\x12L\n\x13\x63ore_instance_fleet\x18\x04 \x01(\x0b\x32/.oak9.tython.aws.emr.ClusterInstanceFleetConfig\x12L\n\x13\x63ore_instance_group\x18\x05 \x01(\x0b\x32/.oak9.tython.aws.emr.ClusterInstanceGroupConfig\x12\x14\n\x0c\x65\x63\x32_key_name\x18\x06 \x01(\t\x12\x15\n\rec2_subnet_id\x18\x07 \x01(\t\x12\x16\n\x0e\x65\x63\x32_subnet_ids\x18\x08 \x03(\t\x12)\n!emr_managed_master_security_group\x18\t \x01(\t\x12(\n emr_managed_slave_security_group\x18\n \x01(\t\x12\x16\n\x0ehadoop_version\x18\x0b \x01(\t\x12)\n!keep_job_flow_alive_when_no_steps\x18\x0c \x01(\x08\x12N\n\x15master_instance_fleet\x18\r \x01(\x0b\x32/.oak9.tython.aws.emr.ClusterInstanceFleetConfig\x12N\n\x15master_instance_group\x18\x0e \x01(\x0b\x32/.oak9.tython.aws.emr.ClusterInstanceGroupConfig\x12<\n\tplacement\x18\x0f \x01(\x0b\x32).oak9.tython.aws.emr.ClusterPlacementType\x12%\n\x1dservice_access_security_group\x18\x10 \x01(\t\x12\x1d\n\x15termination_protected\x18\x11 \x01(\x08\"\xeb\x01\n\x19\x43lusterKerberosAttributes\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1f\n\x17\x61\x64_domain_join_password\x18\x02 \x01(\t\x12\x1b\n\x13\x61\x64_domain_join_user\x18\x03 \x01(\t\x12,\n$cross_realm_trust_principal_password\x18\x04 \x01(\t\x12\x1a\n\x12kdc_admin_password\x18\x05 \x01(\t\x12\r\n\x05realm\x18\x06 \x01(\t\"f\n\x0f\x43lusterKeyValue\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"\xc3\x01\n\x1a\x43lusterHadoopJarStepConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04\x61rgs\x18\x02 \x03(\t\x12\x0b\n\x03jar\x18\x03 \x01(\t\x12\x12\n\nmain_class\x18\x04 \x01(\t\x12=\n\x0fstep_properties\x18\x05 \x03(\x0b\x32$.oak9.tython.aws.emr.ClusterKeyValue\"\xbf\x01\n\x11\x43lusterStepConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x19\n\x11\x61\x63tion_on_failure\x18\x02 \x01(\t\x12H\n\x0fhadoop_jar_step\x18\x03 \x01(\x0b\x32/.oak9.tython.aws.emr.ClusterHadoopJarStepConfig\x12\x0c\n\x04name\x18\x04 \x01(\t\"\xd0\x07\n\x07\x43luster\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12I\n\x0f\x61\x64\x64itional_info\x18\x02 \x03(\x0b\x32\x30.oak9.tython.aws.emr.Cluster.AdditionalInfoEntry\x12=\n\x0c\x61pplications\x18\x03 \x03(\x0b\x32\'.oak9.tython.aws.emr.ClusterApplication\x12\x19\n\x11\x61uto_scaling_role\x18\x04 \x01(\t\x12L\n\x11\x62ootstrap_actions\x18\x05 \x03(\x0b\x32\x31.oak9.tython.aws.emr.ClusterBootstrapActionConfig\x12\x41\n\x0e\x63onfigurations\x18\x06 \x03(\x0b\x32).oak9.tython.aws.emr.ClusterConfiguration\x12\x15\n\rcustom_ami_id\x18\x07 \x01(\t\x12\x1c\n\x14\x65\x62s_root_volume_size\x18\x08 \x01(\x05\x12\x45\n\tinstances\x18\t \x01(\x0b\x32\x32.oak9.tython.aws.emr.ClusterJobFlowInstancesConfig\x12\x15\n\rjob_flow_role\x18\n \x01(\t\x12K\n\x13kerberos_attributes\x18\x0b \x01(\x0b\x32..oak9.tython.aws.emr.ClusterKerberosAttributes\x12\x0f\n\x07log_uri\x18\x0c \x01(\t\x12\x0c\n\x04name\x18\r \x01(\t\x12\x15\n\rrelease_label\x18\x0e \x01(\t\x12\x1b\n\x13scale_down_behavior\x18\x0f \x01(\t\x12\x1e\n\x16security_configuration\x18\x10 \x01(\t\x12\x14\n\x0cservice_role\x18\x11 \x01(\t\x12\x35\n\x05steps\x18\x12 \x03(\x0b\x32&.oak9.tython.aws.emr.ClusterStepConfig\x12\x34\n\x04tags\x18\x13 \x03(\x0b\x32&.oak9.tython.aws.emr.Cluster.TagsEntry\x12\x1c\n\x14visible_to_all_users\x18\x14 \x01(\x08\x1a\x35\n\x13\x41\x64\x64itionalInfoEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xbb\x02\n\x03\x45MR\x12-\n\x07\x63luster\x18\x01 \x03(\x0b\x32\x1c.oak9.tython.aws.emr.Cluster\x12G\n\x15instance_fleet_config\x18\x02 \x03(\x0b\x32(.oak9.tython.aws.emr.InstanceFleetConfig\x12G\n\x15instance_group_config\x18\x03 \x03(\x0b\x32(.oak9.tython.aws.emr.InstanceGroupConfig\x12J\n\x16security_configuration\x18\x04 \x03(\x0b\x32*.oak9.tython.aws.emr.SecurityConfiguration\x12\'\n\x04step\x18\x05 \x03(\x0b\x32\x19.oak9.tython.aws.emr.Step\"\xf8\x02\n InstanceFleetConfigConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0e\x63lassification\x18\x02 \x01(\t\x12t\n\x18\x63onfiguration_properties\x18\x03 \x03(\x0b\x32R.oak9.tython.aws.emr.InstanceFleetConfigConfiguration.ConfigurationPropertiesEntry\x12M\n\x0e\x63onfigurations\x18\x04 \x03(\x0b\x32\x35.oak9.tython.aws.emr.InstanceFleetConfigConfiguration\x1a>\n\x1c\x43onfigurationPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x98\x01\n&InstanceFleetConfigVolumeSpecification\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04iops\x18\x02 \x01(\x05\x12\x12\n\nsize_in_gb\x18\x03 \x01(\x05\x12\x13\n\x0bvolume_type\x18\x04 \x01(\t\"\xdb\x01\n\'InstanceFleetConfigEbsBlockDeviceConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12Y\n\x14volume_specification\x18\x02 \x01(\x0b\x32;.oak9.tython.aws.emr.InstanceFleetConfigVolumeSpecification\x12\x1c\n\x14volumes_per_instance\x18\x03 \x01(\x05\"\xd5\x01\n#InstanceFleetConfigEbsConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12^\n\x18\x65\x62s_block_device_configs\x18\x02 \x03(\x0b\x32<.oak9.tython.aws.emr.InstanceFleetConfigEbsBlockDeviceConfig\x12\x15\n\rebs_optimized\x18\x03 \x01(\x08\"\xfd\x02\n%InstanceFleetConfigInstanceTypeConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\tbid_price\x18\x02 \x01(\t\x12\x32\n*bid_price_as_percentage_of_on_demand_price\x18\x03 \x01(\x01\x12M\n\x0e\x63onfigurations\x18\x04 \x03(\x0b\x32\x35.oak9.tython.aws.emr.InstanceFleetConfigConfiguration\x12S\n\x11\x65\x62s_configuration\x18\x05 \x01(\x0b\x32\x38.oak9.tython.aws.emr.InstanceFleetConfigEbsConfiguration\x12\x15\n\rinstance_type\x18\x06 \x01(\t\x12\x19\n\x11weighted_capacity\x18\x07 \x01(\x05\"\xc5\x01\n0InstanceFleetConfigSpotProvisioningSpecification\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1e\n\x16\x62lock_duration_minutes\x18\x02 \x01(\x05\x12\x16\n\x0etimeout_action\x18\x03 \x01(\t\x12 \n\x18timeout_duration_minutes\x18\x04 \x01(\x05\"\xd8\x01\n:InstanceFleetConfigInstanceFleetProvisioningSpecifications\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x61\n\x12spot_specification\x18\x02 \x01(\x0b\x32\x45.oak9.tython.aws.emr.InstanceFleetConfigSpotProvisioningSpecification\"\x99\x03\n\x13InstanceFleetConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\ncluster_id\x18\x02 \x01(\t\x12\x1b\n\x13instance_fleet_type\x18\x03 \x01(\t\x12Y\n\x15instance_type_configs\x18\x04 \x03(\x0b\x32:.oak9.tython.aws.emr.InstanceFleetConfigInstanceTypeConfig\x12n\n\x15launch_specifications\x18\x05 \x01(\x0b\x32O.oak9.tython.aws.emr.InstanceFleetConfigInstanceFleetProvisioningSpecifications\x12\x0c\n\x04name\x18\x06 \x01(\t\x12!\n\x19target_on_demand_capacity\x18\x07 \x01(\x05\x12\x1c\n\x14target_spot_capacity\x18\x08 \x01(\x05\"\x8c\x01\n%InstanceGroupConfigScalingConstraints\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0cmax_capacity\x18\x02 \x01(\x05\x12\x14\n\x0cmin_capacity\x18\x03 \x01(\x05\"\xb6\x01\n3InstanceGroupConfigSimpleScalingPolicyConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0f\x61\x64justment_type\x18\x02 \x01(\t\x12\x11\n\tcool_down\x18\x03 \x01(\x05\x12\x1a\n\x12scaling_adjustment\x18\x04 \x01(\x05\"\xe2\x01\n InstanceGroupConfigScalingAction\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06market\x18\x02 \x01(\t\x12u\n#simple_scaling_policy_configuration\x18\x03 \x01(\x0b\x32H.oak9.tython.aws.emr.InstanceGroupConfigSimpleScalingPolicyConfiguration\"y\n\"InstanceGroupConfigMetricDimension\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"\xd9\x02\n,InstanceGroupConfigCloudWatchAlarmDefinition\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1b\n\x13\x63omparison_operator\x18\x02 \x01(\t\x12K\n\ndimensions\x18\x03 \x03(\x0b\x32\x37.oak9.tython.aws.emr.InstanceGroupConfigMetricDimension\x12\x1a\n\x12\x65valuation_periods\x18\x04 \x01(\x05\x12\x13\n\x0bmetric_name\x18\x05 \x01(\t\x12\x11\n\tnamespace\x18\x06 \x01(\t\x12\x0e\n\x06period\x18\x07 \x01(\x05\x12\x11\n\tstatistic\x18\x08 \x01(\t\x12\x11\n\tthreshold\x18\t \x01(\x01\x12\x0c\n\x04unit\x18\n \x01(\t\"\xc5\x01\n!InstanceGroupConfigScalingTrigger\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12g\n\x1c\x63loud_watch_alarm_definition\x18\x02 \x01(\x0b\x32\x41.oak9.tython.aws.emr.InstanceGroupConfigCloudWatchAlarmDefinition\"\x8c\x02\n\x1eInstanceGroupConfigScalingRule\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x45\n\x06\x61\x63tion\x18\x02 \x01(\x0b\x32\x35.oak9.tython.aws.emr.InstanceGroupConfigScalingAction\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12G\n\x07trigger\x18\x05 \x01(\x0b\x32\x36.oak9.tython.aws.emr.InstanceGroupConfigScalingTrigger\"\xf4\x01\n$InstanceGroupConfigAutoScalingPolicy\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12O\n\x0b\x63onstraints\x18\x02 \x01(\x0b\x32:.oak9.tython.aws.emr.InstanceGroupConfigScalingConstraints\x12\x42\n\x05rules\x18\x03 \x03(\x0b\x32\x33.oak9.tython.aws.emr.InstanceGroupConfigScalingRule\"\xf8\x02\n InstanceGroupConfigConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0e\x63lassification\x18\x02 \x01(\t\x12t\n\x18\x63onfiguration_properties\x18\x03 \x03(\x0b\x32R.oak9.tython.aws.emr.InstanceGroupConfigConfiguration.ConfigurationPropertiesEntry\x12M\n\x0e\x63onfigurations\x18\x04 \x03(\x0b\x32\x35.oak9.tython.aws.emr.InstanceGroupConfigConfiguration\x1a>\n\x1c\x43onfigurationPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x98\x01\n&InstanceGroupConfigVolumeSpecification\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04iops\x18\x02 \x01(\x05\x12\x12\n\nsize_in_gb\x18\x03 \x01(\x05\x12\x13\n\x0bvolume_type\x18\x04 \x01(\t\"\xdb\x01\n\'InstanceGroupConfigEbsBlockDeviceConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12Y\n\x14volume_specification\x18\x02 \x01(\x0b\x32;.oak9.tython.aws.emr.InstanceGroupConfigVolumeSpecification\x12\x1c\n\x14volumes_per_instance\x18\x03 \x01(\x05\"\xd5\x01\n#InstanceGroupConfigEbsConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12^\n\x18\x65\x62s_block_device_configs\x18\x02 \x03(\x0b\x32<.oak9.tython.aws.emr.InstanceGroupConfigEbsBlockDeviceConfig\x12\x15\n\rebs_optimized\x18\x03 \x01(\x08\"\xd6\x03\n\x13InstanceGroupConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12V\n\x13\x61uto_scaling_policy\x18\x02 \x01(\x0b\x32\x39.oak9.tython.aws.emr.InstanceGroupConfigAutoScalingPolicy\x12\x11\n\tbid_price\x18\x03 \x01(\t\x12M\n\x0e\x63onfigurations\x18\x04 \x03(\x0b\x32\x35.oak9.tython.aws.emr.InstanceGroupConfigConfiguration\x12S\n\x11\x65\x62s_configuration\x18\x05 \x01(\x0b\x32\x38.oak9.tython.aws.emr.InstanceGroupConfigEbsConfiguration\x12\x16\n\x0einstance_count\x18\x06 \x01(\x05\x12\x15\n\rinstance_role\x18\x07 \x01(\t\x12\x15\n\rinstance_type\x18\x08 \x01(\t\x12\x13\n\x0bjob_flow_id\x18\t \x01(\t\x12\x0e\n\x06market\x18\n \x01(\t\x12\x0c\n\x04name\x18\x0b \x01(\t\"\x83\x02\n\x15SecurityConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x65\n\x16security_configuration\x18\x03 \x03(\x0b\x32\x45.oak9.tython.aws.emr.SecurityConfiguration.SecurityConfigurationEntry\x1a<\n\x1aSecurityConfigurationEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"c\n\x0cStepKeyValue\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"\xbd\x01\n\x17StepHadoopJarStepConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04\x61rgs\x18\x02 \x03(\t\x12\x0b\n\x03jar\x18\x03 \x01(\t\x12\x12\n\nmain_class\x18\x04 \x01(\t\x12:\n\x0fstep_properties\x18\x05 \x03(\x0b\x32!.oak9.tython.aws.emr.StepKeyValue\"\xc4\x01\n\x04Step\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x19\n\x11\x61\x63tion_on_failure\x18\x02 \x01(\t\x12\x45\n\x0fhadoop_jar_step\x18\x03 \x01(\x0b\x32,.oak9.tython.aws.emr.StepHadoopJarStepConfig\x12\x13\n\x0bjob_flow_id\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_emr_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CLUSTERAPPLICATION_ADDITIONALINFOENTRY._options = None
  _CLUSTERAPPLICATION_ADDITIONALINFOENTRY._serialized_options = b'8\001'
  _CLUSTERCONFIGURATION_CONFIGURATIONPROPERTIESENTRY._options = None
  _CLUSTERCONFIGURATION_CONFIGURATIONPROPERTIESENTRY._serialized_options = b'8\001'
  _CLUSTER_ADDITIONALINFOENTRY._options = None
  _CLUSTER_ADDITIONALINFOENTRY._serialized_options = b'8\001'
  _CLUSTER_TAGSENTRY._options = None
  _CLUSTER_TAGSENTRY._serialized_options = b'8\001'
  _INSTANCEFLEETCONFIGCONFIGURATION_CONFIGURATIONPROPERTIESENTRY._options = None
  _INSTANCEFLEETCONFIGCONFIGURATION_CONFIGURATIONPROPERTIESENTRY._serialized_options = b'8\001'
  _INSTANCEGROUPCONFIGCONFIGURATION_CONFIGURATIONPROPERTIESENTRY._options = None
  _INSTANCEGROUPCONFIGCONFIGURATION_CONFIGURATIONPROPERTIESENTRY._serialized_options = b'8\001'
  _SECURITYCONFIGURATION_SECURITYCONFIGURATIONENTRY._options = None
  _SECURITYCONFIGURATION_SECURITYCONFIGURATIONENTRY._serialized_options = b'8\001'
  _CLUSTERAPPLICATION._serialized_start=64
  _CLUSTERAPPLICATION._serialized_end=327
  _CLUSTERAPPLICATION_ADDITIONALINFOENTRY._serialized_start=274
  _CLUSTERAPPLICATION_ADDITIONALINFOENTRY._serialized_end=327
  _CLUSTERSCRIPTBOOTSTRAPACTIONCONFIG._serialized_start=329
  _CLUSTERSCRIPTBOOTSTRAPACTIONCONFIG._serialized_end=450
  _CLUSTERBOOTSTRAPACTIONCONFIG._serialized_start=453
  _CLUSTERBOOTSTRAPACTIONCONFIG._serialized_end=644
  _CLUSTERCONFIGURATION._serialized_start=647
  _CLUSTERCONFIGURATION._serialized_end=987
  _CLUSTERCONFIGURATION_CONFIGURATIONPROPERTIESENTRY._serialized_start=925
  _CLUSTERCONFIGURATION_CONFIGURATIONPROPERTIESENTRY._serialized_end=987
  _CLUSTERVOLUMESPECIFICATION._serialized_start=990
  _CLUSTERVOLUMESPECIFICATION._serialized_end=1130
  _CLUSTEREBSBLOCKDEVICECONFIG._serialized_start=1133
  _CLUSTEREBSBLOCKDEVICECONFIG._serialized_end=1328
  _CLUSTEREBSCONFIGURATION._serialized_start=1331
  _CLUSTEREBSCONFIGURATION._serialized_end=1520
  _CLUSTERINSTANCETYPECONFIG._serialized_start=1523
  _CLUSTERINSTANCETYPECONFIG._serialized_end=1868
  _CLUSTERSPOTPROVISIONINGSPECIFICATION._serialized_start=1871
  _CLUSTERSPOTPROVISIONINGSPECIFICATION._serialized_end=2056
  _CLUSTERINSTANCEFLEETPROVISIONINGSPECIFICATIONS._serialized_start=2059
  _CLUSTERINSTANCEFLEETPROVISIONINGSPECIFICATIONS._serialized_end=2251
  _CLUSTERINSTANCEFLEETCONFIG._serialized_start=2254
  _CLUSTERINSTANCEFLEETCONFIG._serialized_end=2597
  _CLUSTERSCALINGCONSTRAINTS._serialized_start=2600
  _CLUSTERSCALINGCONSTRAINTS._serialized_end=2728
  _CLUSTERSIMPLESCALINGPOLICYCONFIGURATION._serialized_start=2731
  _CLUSTERSIMPLESCALINGPOLICYCONFIGURATION._serialized_end=2901
  _CLUSTERSCALINGACTION._serialized_start=2904
  _CLUSTERSCALINGACTION._serialized_end=3106
  _CLUSTERMETRICDIMENSION._serialized_start=3108
  _CLUSTERMETRICDIMENSION._serialized_end=3217
  _CLUSTERCLOUDWATCHALARMDEFINITION._serialized_start=3220
  _CLUSTERCLOUDWATCHALARMDEFINITION._serialized_end=3541
  _CLUSTERSCALINGTRIGGER._serialized_start=3544
  _CLUSTERSCALINGTRIGGER._serialized_end=3717
  _CLUSTERSCALINGRULE._serialized_start=3720
  _CLUSTERSCALINGRULE._serialized_end=3952
  _CLUSTERAUTOSCALINGPOLICY._serialized_start=3955
  _CLUSTERAUTOSCALINGPOLICY._serialized_end=4163
  _CLUSTERINSTANCEGROUPCONFIG._serialized_start=4166
  _CLUSTERINSTANCEGROUPCONFIG._serialized_end=4563
  _CLUSTERPLACEMENTTYPE._serialized_start=4565
  _CLUSTERPLACEMENTTYPE._serialized_end=4671
  _CLUSTERJOBFLOWINSTANCESCONFIG._serialized_start=4674
  _CLUSTERJOBFLOWINSTANCESCONFIG._serialized_end=5516
  _CLUSTERKERBEROSATTRIBUTES._serialized_start=5519
  _CLUSTERKERBEROSATTRIBUTES._serialized_end=5754
  _CLUSTERKEYVALUE._serialized_start=5756
  _CLUSTERKEYVALUE._serialized_end=5858
  _CLUSTERHADOOPJARSTEPCONFIG._serialized_start=5861
  _CLUSTERHADOOPJARSTEPCONFIG._serialized_end=6056
  _CLUSTERSTEPCONFIG._serialized_start=6059
  _CLUSTERSTEPCONFIG._serialized_end=6250
  _CLUSTER._serialized_start=6253
  _CLUSTER._serialized_end=7229
  _CLUSTER_ADDITIONALINFOENTRY._serialized_start=274
  _CLUSTER_ADDITIONALINFOENTRY._serialized_end=327
  _CLUSTER_TAGSENTRY._serialized_start=7186
  _CLUSTER_TAGSENTRY._serialized_end=7229
  _EMR._serialized_start=7232
  _EMR._serialized_end=7547
  _INSTANCEFLEETCONFIGCONFIGURATION._serialized_start=7550
  _INSTANCEFLEETCONFIGCONFIGURATION._serialized_end=7926
  _INSTANCEFLEETCONFIGCONFIGURATION_CONFIGURATIONPROPERTIESENTRY._serialized_start=925
  _INSTANCEFLEETCONFIGCONFIGURATION_CONFIGURATIONPROPERTIESENTRY._serialized_end=987
  _INSTANCEFLEETCONFIGVOLUMESPECIFICATION._serialized_start=7929
  _INSTANCEFLEETCONFIGVOLUMESPECIFICATION._serialized_end=8081
  _INSTANCEFLEETCONFIGEBSBLOCKDEVICECONFIG._serialized_start=8084
  _INSTANCEFLEETCONFIGEBSBLOCKDEVICECONFIG._serialized_end=8303
  _INSTANCEFLEETCONFIGEBSCONFIGURATION._serialized_start=8306
  _INSTANCEFLEETCONFIGEBSCONFIGURATION._serialized_end=8519
  _INSTANCEFLEETCONFIGINSTANCETYPECONFIG._serialized_start=8522
  _INSTANCEFLEETCONFIGINSTANCETYPECONFIG._serialized_end=8903
  _INSTANCEFLEETCONFIGSPOTPROVISIONINGSPECIFICATION._serialized_start=8906
  _INSTANCEFLEETCONFIGSPOTPROVISIONINGSPECIFICATION._serialized_end=9103
  _INSTANCEFLEETCONFIGINSTANCEFLEETPROVISIONINGSPECIFICATIONS._serialized_start=9106
  _INSTANCEFLEETCONFIGINSTANCEFLEETPROVISIONINGSPECIFICATIONS._serialized_end=9322
  _INSTANCEFLEETCONFIG._serialized_start=9325
  _INSTANCEFLEETCONFIG._serialized_end=9734
  _INSTANCEGROUPCONFIGSCALINGCONSTRAINTS._serialized_start=9737
  _INSTANCEGROUPCONFIGSCALINGCONSTRAINTS._serialized_end=9877
  _INSTANCEGROUPCONFIGSIMPLESCALINGPOLICYCONFIGURATION._serialized_start=9880
  _INSTANCEGROUPCONFIGSIMPLESCALINGPOLICYCONFIGURATION._serialized_end=10062
  _INSTANCEGROUPCONFIGSCALINGACTION._serialized_start=10065
  _INSTANCEGROUPCONFIGSCALINGACTION._serialized_end=10291
  _INSTANCEGROUPCONFIGMETRICDIMENSION._serialized_start=10293
  _INSTANCEGROUPCONFIGMETRICDIMENSION._serialized_end=10414
  _INSTANCEGROUPCONFIGCLOUDWATCHALARMDEFINITION._serialized_start=10417
  _INSTANCEGROUPCONFIGCLOUDWATCHALARMDEFINITION._serialized_end=10762
  _INSTANCEGROUPCONFIGSCALINGTRIGGER._serialized_start=10765
  _INSTANCEGROUPCONFIGSCALINGTRIGGER._serialized_end=10962
  _INSTANCEGROUPCONFIGSCALINGRULE._serialized_start=10965
  _INSTANCEGROUPCONFIGSCALINGRULE._serialized_end=11233
  _INSTANCEGROUPCONFIGAUTOSCALINGPOLICY._serialized_start=11236
  _INSTANCEGROUPCONFIGAUTOSCALINGPOLICY._serialized_end=11480
  _INSTANCEGROUPCONFIGCONFIGURATION._serialized_start=11483
  _INSTANCEGROUPCONFIGCONFIGURATION._serialized_end=11859
  _INSTANCEGROUPCONFIGCONFIGURATION_CONFIGURATIONPROPERTIESENTRY._serialized_start=925
  _INSTANCEGROUPCONFIGCONFIGURATION_CONFIGURATIONPROPERTIESENTRY._serialized_end=987
  _INSTANCEGROUPCONFIGVOLUMESPECIFICATION._serialized_start=11862
  _INSTANCEGROUPCONFIGVOLUMESPECIFICATION._serialized_end=12014
  _INSTANCEGROUPCONFIGEBSBLOCKDEVICECONFIG._serialized_start=12017
  _INSTANCEGROUPCONFIGEBSBLOCKDEVICECONFIG._serialized_end=12236
  _INSTANCEGROUPCONFIGEBSCONFIGURATION._serialized_start=12239
  _INSTANCEGROUPCONFIGEBSCONFIGURATION._serialized_end=12452
  _INSTANCEGROUPCONFIG._serialized_start=12455
  _INSTANCEGROUPCONFIG._serialized_end=12925
  _SECURITYCONFIGURATION._serialized_start=12928
  _SECURITYCONFIGURATION._serialized_end=13187
  _SECURITYCONFIGURATION_SECURITYCONFIGURATIONENTRY._serialized_start=13127
  _SECURITYCONFIGURATION_SECURITYCONFIGURATIONENTRY._serialized_end=13187
  _STEPKEYVALUE._serialized_start=13189
  _STEPKEYVALUE._serialized_end=13288
  _STEPHADOOPJARSTEPCONFIG._serialized_start=13291
  _STEPHADOOPJARSTEPCONFIG._serialized_end=13480
  _STEP._serialized_start=13483
  _STEP._serialized_end=13679
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_tags.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12gcp/gcp_tags.proto\x12\x14oak9.tython.gcp.tags\x1a\x13shared/shared.proto\"9\n\x17TagsTagBindingXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"\xc7\x01\n\x0eTagsTagBinding\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06parent\x18\x03 \x01(\t\x12\x11\n\ttag_value\x18\x04 \x01(\t\x12?\n\x08timeouts\x18\x05 \x01(\x0b\x32-.oak9.tython.gcp.tags.TagsTagBindingXTimeouts\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"E\n\x13TagsTagKeyXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\x98\x02\n\nTagsTagKey\x12\x13\n\x0b\x63reate_time\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x17\n\x0fnamespaced_name\x18\x05 \x01(\t\x12\x0e\n\x06parent\x18\x06 \x01(\t\x12\x12\n\nshort_name\x18\x07 \x01(\t\x12\x13\n\x0bupdate_time\x18\x08 \x01(\t\x12;\n\x08timeouts\x18\t \x01(\x0b\x32).oak9.tython.gcp.tags.TagsTagKeyXTimeouts\x12\x37\n\rresource_info\x18\n \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"X\n\x1eTagsTagKeyIamBindingXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\xe2\x01\n\x14TagsTagKeyIamBinding\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0f\n\x07members\x18\x03 \x03(\t\x12\x0c\n\x04role\x18\x04 \x01(\t\x12\x0f\n\x07tag_key\x18\x05 \x01(\t\x12G\n\tcondition\x18\x06 \x01(\x0b\x32\x34.oak9.tython.gcp.tags.TagsTagKeyIamBindingXCondition\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"W\n\x1dTagsTagKeyIamMemberXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\xdf\x01\n\x13TagsTagKeyIamMember\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0e\n\x06member\x18\x03 \x01(\t\x12\x0c\n\x04role\x18\x04 \x01(\t\x12\x0f\n\x07tag_key\x18\x05 \x01(\t\x12\x46\n\tcondition\x18\x06 \x01(\x0b\x32\x33.oak9.tython.gcp.tags.TagsTagKeyIamMemberXCondition\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x8e\x01\n\x13TagsTagKeyIamPolicy\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x13\n\x0bpolicy_data\x18\x03 \x01(\t\x12\x0f\n\x07tag_key\x18\x04 \x01(\t\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"G\n\x15TagsTagValueXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\x9c\x02\n\x0cTagsTagValue\x12\x13\n\x0b\x63reate_time\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x17\n\x0fnamespaced_name\x18\x05 \x01(\t\x12\x0e\n\x06parent\x18\x06 \x01(\t\x12\x12\n\nshort_name\x18\x07 \x01(\t\x12\x13\n\x0bupdate_time\x18\x08 \x01(\t\x12=\n\x08timeouts\x18\t \x01(\x0b\x32+.oak9.tython.gcp.tags.TagsTagValueXTimeouts\x12\x37\n\rresource_info\x18\n \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"Z\n TagsTagValueIamBindingXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\xe8\x01\n\x16TagsTagValueIamBinding\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0f\n\x07members\x18\x03 \x03(\t\x12\x0c\n\x04role\x18\x04 \x01(\t\x12\x11\n\ttag_value\x18\x05 \x01(\t\x12I\n\tcondition\x18\x06 \x01(\x0b\x32\x36.oak9.tython.gcp.tags.TagsTagValueIamBindingXCondition\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"Y\n\x1fTagsTagValueIamMemberXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\xe5\x01\n\x15TagsTagValueIamMember\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0e\n\x06member\x18\x03 \x01(\t\x12\x0c\n\x04role\x18\x04 \x01(\t\x12\x11\n\ttag_value\x18\x05 \x01(\t\x12H\n\tcondition\x18\x06 \x01(\x0b\x32\x35.oak9.tython.gcp.tags.TagsTagValueIamMemberXCondition\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x92\x01\n\x15TagsTagValueIamPolicy\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x13\n\x0bpolicy_data\x18\x03 \x01(\t\x12\x11\n\ttag_value\x18\x04 \x01(\t\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_tags_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TAGSTAGBINDINGXTIMEOUTS._serialized_start=65
  _TAGSTAGBINDINGXTIMEOUTS._serialized_end=122
  _TAGSTAGBINDING._serialized_start=125
  _TAGSTAGBINDING._serialized_end=324
  _TAGSTAGKEYXTIMEOUTS._serialized_start=326
  _TAGSTAGKEYXTIMEOUTS._serialized_end=395
  _TAGSTAGKEY._serialized_start=398
  _TAGSTAGKEY._serialized_end=678
  _TAGSTAGKEYIAMBINDINGXCONDITION._serialized_start=680
  _TAGSTAGKEYIAMBINDINGXCONDITION._serialized_end=768
  _TAGSTAGKEYIAMBINDING._serialized_start=771
  _TAGSTAGKEYIAMBINDING._serialized_end=997
  _TAGSTAGKEYIAMMEMBERXCONDITION._serialized_start=999
  _TAGSTAGKEYIAMMEMBERXCONDITION._serialized_end=1086
  _TAGSTAGKEYIAMMEMBER._serialized_start=1089
  _TAGSTAGKEYIAMMEMBER._serialized_end=1312
  _TAGSTAGKEYIAMPOLICY._serialized_start=1315
  _TAGSTAGKEYIAMPOLICY._serialized_end=1457
  _TAGSTAGVALUEXTIMEOUTS._serialized_start=1459
  _TAGSTAGVALUEXTIMEOUTS._serialized_end=1530
  _TAGSTAGVALUE._serialized_start=1533
  _TAGSTAGVALUE._serialized_end=1817
  _TAGSTAGVALUEIAMBINDINGXCONDITION._serialized_start=1819
  _TAGSTAGVALUEIAMBINDINGXCONDITION._serialized_end=1909
  _TAGSTAGVALUEIAMBINDING._serialized_start=1912
  _TAGSTAGVALUEIAMBINDING._serialized_end=2144
  _TAGSTAGVALUEIAMMEMBERXCONDITION._serialized_start=2146
  _TAGSTAGVALUEIAMMEMBERXCONDITION._serialized_end=2235
  _TAGSTAGVALUEIAMMEMBER._serialized_start=2238
  _TAGSTAGVALUEIAMMEMBER._serialized_end=2467
  _TAGSTAGVALUEIAMPOLICY._serialized_start=2470
  _TAGSTAGVALUEIAMPOLICY._serialized_end=2616
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_ml.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10gcp/gcp_ml.proto\x12\x12oak9.tython.gcp.ml\x1a\x13shared/shared.proto\",\n\x1cMlEngineModelXDefaultVersion\x12\x0c\n\x04name\x18\x01 \x01(\t\"8\n\x16MlEngineModelXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"\xde\x03\n\rMlEngineModel\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12=\n\x06labels\x18\x03 \x03(\x0b\x32-.oak9.tython.gcp.ml.MlEngineModel.LabelsEntry\x12\x0c\n\x04name\x18\x04 \x01(\t\x12)\n!online_prediction_console_logging\x18\x05 \x01(\x08\x12!\n\x19online_prediction_logging\x18\x06 \x01(\x08\x12\x0f\n\x07project\x18\x07 \x01(\t\x12\x0f\n\x07regions\x18\x08 \x03(\t\x12I\n\x0f\x64\x65\x66\x61ult_version\x18\t \x01(\x0b\x32\x30.oak9.tython.gcp.ml.MlEngineModelXDefaultVersion\x12<\n\x08timeouts\x18\n \x01(\x0b\x32*.oak9.tython.gcp.ml.MlEngineModelXTimeouts\x12\x37\n\rresource_info\x18\x0b \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_ml_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _MLENGINEMODEL_LABELSENTRY._options = None
  _MLENGINEMODEL_LABELSENTRY._serialized_options = b'8\001'
  _MLENGINEMODELXDEFAULTVERSION._serialized_start=61
  _MLENGINEMODELXDEFAULTVERSION._serialized_end=105
  _MLENGINEMODELXTIMEOUTS._serialized_start=107
  _MLENGINEMODELXTIMEOUTS._serialized_end=163
  _MLENGINEMODEL._serialized_start=166
  _MLENGINEMODEL._serialized_end=644
  _MLENGINEMODEL_LABELSENTRY._serialized_start=599
  _MLENGINEMODEL_LABELSENTRY._serialized_end=644
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ResourcePolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    SECRET_ID_FIELD_NUMBER: builtins.int
    RESOURCE_POLICY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    secret_id: builtins.str
    resource_policy: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        secret_id: builtins.str = ...,
        resource_policy: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "resource_policy", b"resource_policy", "secret_id", b"secret_id"]) -> None: ...

global___ResourcePolicy = ResourcePolicy

@typing_extensions.final
class SecretsManager(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_POLICY_FIELD_NUMBER: builtins.int
    ROTATION_SCHEDULE_FIELD_NUMBER: builtins.int
    SECRET_FIELD_NUMBER: builtins.int
    SECRET_TARGET_ATTACHMENT_FIELD_NUMBER: builtins.int
    @property
    def resource_policy(self) -> global___ResourcePolicy: ...
    @property
    def rotation_schedule(self) -> global___RotationSchedule: ...
    @property
    def secret(self) -> global___Secret: ...
    @property
    def secret_target_attachment(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SecretTargetAttachment]: ...
    def __init__(
        self,
        *,
        resource_policy: global___ResourcePolicy | None = ...,
        rotation_schedule: global___RotationSchedule | None = ...,
        secret: global___Secret | None = ...,
        secret_target_attachment: collections.abc.Iterable[global___SecretTargetAttachment] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_policy", b"resource_policy", "rotation_schedule", b"rotation_schedule", "secret", b"secret"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_policy", b"resource_policy", "rotation_schedule", b"rotation_schedule", "secret", b"secret", "secret_target_attachment", b"secret_target_attachment"]) -> None: ...

global___SecretsManager = SecretsManager

@typing_extensions.final
class RotationScheduleHostedRotationLambda(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ROTATION_TYPE_FIELD_NUMBER: builtins.int
    ROTATION_LAMBDA_NAME_FIELD_NUMBER: builtins.int
    KMS_KEY_ARN_FIELD_NUMBER: builtins.int
    MASTER_SECRET_ARN_FIELD_NUMBER: builtins.int
    VPC_SECURITY_GROUP_IDS_FIELD_NUMBER: builtins.int
    MASTER_SECRET_KMS_KEY_ARN_FIELD_NUMBER: builtins.int
    VPC_SUBNET_IDS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    rotation_type: builtins.str
    rotation_lambda_name: builtins.str
    kms_key_arn: builtins.str
    master_secret_arn: builtins.str
    vpc_security_group_ids: builtins.str
    master_secret_kms_key_arn: builtins.str
    vpc_subnet_ids: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        rotation_type: builtins.str = ...,
        rotation_lambda_name: builtins.str = ...,
        kms_key_arn: builtins.str = ...,
        master_secret_arn: builtins.str = ...,
        vpc_security_group_ids: builtins.str = ...,
        master_secret_kms_key_arn: builtins.str = ...,
        vpc_subnet_ids: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["kms_key_arn", b"kms_key_arn", "master_secret_arn", b"master_secret_arn", "master_secret_kms_key_arn", b"master_secret_kms_key_arn", "resource_info", b"resource_info", "rotation_lambda_name", b"rotation_lambda_name", "rotation_type", b"rotation_type", "vpc_security_group_ids", b"vpc_security_group_ids", "vpc_subnet_ids", b"vpc_subnet_ids"]) -> None: ...

global___RotationScheduleHostedRotationLambda = RotationScheduleHostedRotationLambda

@typing_extensions.final
class RotationScheduleRotationRules(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    AUTOMATICALLY_AFTER_DAYS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    automatically_after_days: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        automatically_after_days: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["automatically_after_days", b"automatically_after_days", "resource_info", b"resource_info"]) -> None: ...

global___RotationScheduleRotationRules = RotationScheduleRotationRules

@typing_extensions.final
class RotationSchedule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    SECRET_ID_FIELD_NUMBER: builtins.int
    HOSTED_ROTATION_LAMBDA_FIELD_NUMBER: builtins.int
    ROTATION_LAMBDA_ARN_FIELD_NUMBER: builtins.int
    ROTATION_RULES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    secret_id: builtins.str
    @property
    def hosted_rotation_lambda(self) -> global___RotationScheduleHostedRotationLambda: ...
    rotation_lambda_arn: builtins.str
    @property
    def rotation_rules(self) -> global___RotationScheduleRotationRules: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        secret_id: builtins.str = ...,
        hosted_rotation_lambda: global___RotationScheduleHostedRotationLambda | None = ...,
        rotation_lambda_arn: builtins.str = ...,
        rotation_rules: global___RotationScheduleRotationRules | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["hosted_rotation_lambda", b"hosted_rotation_lambda", "resource_info", b"resource_info", "rotation_rules", b"rotation_rules"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["hosted_rotation_lambda", b"hosted_rotation_lambda", "resource_info", b"resource_info", "rotation_lambda_arn", b"rotation_lambda_arn", "rotation_rules", b"rotation_rules", "secret_id", b"secret_id"]) -> None: ...

global___RotationSchedule = RotationSchedule

@typing_extensions.final
class SecretGenerateSecretString(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    EXCLUDE_UPPERCASE_FIELD_NUMBER: builtins.int
    REQUIRE_EACH_INCLUDED_TYPE_FIELD_NUMBER: builtins.int
    INCLUDE_SPACE_FIELD_NUMBER: builtins.int
    EXCLUDE_CHARACTERS_FIELD_NUMBER: builtins.int
    GENERATE_STRING_KEY_FIELD_NUMBER: builtins.int
    PASSWORD_LENGTH_FIELD_NUMBER: builtins.int
    EXCLUDE_PUNCTUATION_FIELD_NUMBER: builtins.int
    EXCLUDE_LOWERCASE_FIELD_NUMBER: builtins.int
    SECRET_STRING_TEMPLATE_FIELD_NUMBER: builtins.int
    EXCLUDE_NUMBERS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    exclude_uppercase: builtins.bool
    require_each_included_type: builtins.bool
    include_space: builtins.bool
    exclude_characters: builtins.str
    generate_string_key: builtins.str
    password_length: builtins.int
    exclude_punctuation: builtins.bool
    exclude_lowercase: builtins.bool
    secret_string_template: builtins.str
    exclude_numbers: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        exclude_uppercase: builtins.bool = ...,
        require_each_included_type: builtins.bool = ...,
        include_space: builtins.bool = ...,
        exclude_characters: builtins.str = ...,
        generate_string_key: builtins.str = ...,
        password_length: builtins.int = ...,
        exclude_punctuation: builtins.bool = ...,
        exclude_lowercase: builtins.bool = ...,
        secret_string_template: builtins.str = ...,
        exclude_numbers: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["exclude_characters", b"exclude_characters", "exclude_lowercase", b"exclude_lowercase", "exclude_numbers", b"exclude_numbers", "exclude_punctuation", b"exclude_punctuation", "exclude_uppercase", b"exclude_uppercase", "generate_string_key", b"generate_string_key", "include_space", b"include_space", "password_length", b"password_length", "require_each_included_type", b"require_each_included_type", "resource_info", b"resource_info", "secret_string_template", b"secret_string_template"]) -> None: ...

global___SecretGenerateSecretString = SecretGenerateSecretString

@typing_extensions.final
class Secret(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    KMS_KEY_ID_FIELD_NUMBER: builtins.int
    SECRET_STRING_FIELD_NUMBER: builtins.int
    GENERATE_SECRET_STRING_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    description: builtins.str
    kms_key_id: builtins.str
    secret_string: builtins.str
    @property
    def generate_secret_string(self) -> global___SecretGenerateSecretString: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        description: builtins.str = ...,
        kms_key_id: builtins.str = ...,
        secret_string: builtins.str = ...,
        generate_secret_string: global___SecretGenerateSecretString | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["generate_secret_string", b"generate_secret_string", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "generate_secret_string", b"generate_secret_string", "kms_key_id", b"kms_key_id", "name", b"name", "resource_info", b"resource_info", "secret_string", b"secret_string", "tags", b"tags"]) -> None: ...

global___Secret = Secret

@typing_extensions.final
class SecretTargetAttachment(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    SECRET_ID_FIELD_NUMBER: builtins.int
    TARGET_TYPE_FIELD_NUMBER: builtins.int
    TARGET_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    secret_id: builtins.str
    target_type: builtins.str
    target_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        secret_id: builtins.str = ...,
        target_type: builtins.str = ...,
        target_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "secret_id", b"secret_id", "target_id", b"target_id", "target_type", b"target_type"]) -> None: ...

global___SecretTargetAttachment = SecretTargetAttachment
